#[non_exhaustive]pub enum ActiveSpellGate {
IgnoreAuraState,
DisableAbilities,
}Expand description
Availability behavior contributed by an active DBC aura effect.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IgnoreAuraState
Waive aura-state requirements for affected spells while the aura is active (aura 262).
DisableAbilities
Disable affected spells while the aura is active (aura 263).